-- XAutoRepair by Xzandro
XAR = {}
XAR.Saved = {}
XAR.Defaults = {
    onlyEquiped = true,
    hideNoRepairMsg = false,
    hideAllMsg = false
}

function XAR.init(eventCode, addOnName)
    if addOnName ~= "XAutoRepair" then
        return
    end
    XAR.Options()
    XAR.Saved = ZO_SavedVars:New("XAR_Vars", 1, nil, XAR.Defaults, nil)
    d("XAutoRepair loaded")

    EVENT_MANAGER:RegisterForEvent("XAutoRepair", EVENT_OPEN_STORE, XAR.OnShopOpen)
end

function XAR.OnShopOpen()
    local cost = GetRepairAllCost()
    if GetCurrentMoney() >= cost then
        if XAR.Saved.onlyEquiped then
            XAR.RepairOnlyEquippedItems()
        else
            XAR.RepairAllItems()
        end
    else
         XAR.print("Not enough gold")
    end
end

function XAR.RepairAllItems()
    local cost = GetRepairAllCost()
    if cost > 0 then
        RepairAll()
        XAR.print("All Items Repaired. Costs: " .. cost .. " Gold")
    else
         XAR.print("Nothing to repair.")
    end
end

function XAR.RepairOnlyEquippedItems()
    local _, bagSlots = GetBagInfo(BAG_WORN)
    local costEquiped = 0;
    for slotIndex=0, bagSlots - 1 do
        local condition = GetItemCondition(bagId, slotIndex)
        if condition < 100 then
            local icon, stackCount, _, _, _, _, _, quality = GetItemInfo(bagId, slotIndex)
            if stackCount > 0 then
                local repairCost = GetItemRepairCost(bagId, slotIndex)
                if repairCost > 0 then
                    costEquiped = costEquiped + repairCost;
                    RepairItem(bagId, slotIndex)
                end
            end
        end
    end
    if costEquiped > 0 then
        XAR.print("Equiped Items Repaired. Costs: " .. costEquiped .. " Gold")
    else
        if XAR.Saved.hideNoRepairMsg == false then
            XAR.print("Nothing to repair.")
        end
    end
end

function XAR.Options()
    local LAM = LibStub("LibAddonMenu-1.0")
    local XCollectionsPanel = LAM:CreateControlPanel("XCOLLECTIONS_ADDON_OPTIONS", "XCollections")
    LAM:AddHeader(XCollectionsPanel, "XAutoRepair_Options_Header", "XAutoRepair")
    LAM:AddCheckbox(XCollectionsPanel, "XAutoRepair_Options_Equiped", "Only equiped items", "Repair only equipped items?",
                    function() return XAR.Saved.onlyEquiped end,
                    function(val) XAR.Saved.onlyEquiped = val end)
    LAM:AddCheckbox(XCollectionsPanel, "XAutoRepair_Options_HideNothingToRepair", "Hide 'Nothing to Repair' message", "Hide 'Nothing to Repair' message. You will see a message if there is something to repair, though.",
                    function() return XAR.Saved.hideNoRepairMsg end,
                    function(val) XAR.Saved.hideNoRepairMsg = val end)
    LAM:AddCheckbox(XCollectionsPanel, "XAutoRepair_Options_HideAllMsg", "Hide ALL messages", "Silent-Mode: no message will be displayed. You also won't see your repair cost.",
                    function() return XAR.Saved.hideAllMsg end,
                    function(val) XAR.Saved.hideAllMsg = val end)
end

function XAR.print(msg)
    if XAR.Saved.hideAllMsg then return end
    d("XAutoRepair: " .. msg)
end

EVENT_MANAGER:RegisterForEvent("XAutoRepair", EVENT_ADD_ON_LOADED, XAR.init)